LightConfig

Struct LightConfig 

pub struct LightConfig {
Show 28 fields pub disable_interior_sun: bool, pub disable_flickering: bool, pub disable_pulse: bool, pub disable_negative_lights: bool, pub auto_enable: bool, pub no_notifications: bool, pub debug: bool, pub dry_run: bool, pub validate_config: bool, pub standard_hue: f32, pub standard_saturation: f32, pub standard_value: f32, pub standard_radius: f32, pub colored_hue: f32, pub colored_saturation: f32, pub colored_value: f32, pub colored_radius: f32, pub duration_mult: f32, pub excluded_plugins: Vec<String>, pub excluded_ids: Vec<String>, pub light_overrides: OrderedHashMap<String, CustomLightData>, pub ambient_overrides: OrderedHashMap<String, CustomCellAmbient>, pub output_dir: Option<PathBuf>, pub save_config: bool, pub excluded_id_regexes: Vec<Regex>, pub excluded_plugin_regexes: Vec<Regex>, pub light_regexes: Vec<(Regex, CustomLightData)>, pub ambient_regexes: Vec<(Regex, CustomCellAmbient)>,
}

Fields

disable_interior_sun: bool

This parameter is DANGEROUS It’s only meant to be used with vtastek’s experimental shaders for openmw 0.47 https://discord.com/channels/260439894298460160/718892786157617163/966468825321177148

disable_flickering: booldisable_pulse: booldisable_negative_lights: boolauto_enable: boolno_notifications: booldebug: booldry_run: boolvalidate_config: boolstandard_hue: f32standard_saturation: f32standard_value: f32standard_radius: f32colored_hue: f32colored_saturation: f32colored_value: f32colored_radius: f32duration_mult: f32excluded_plugins: Vec<String>excluded_ids: Vec<String>light_overrides: OrderedHashMap<String, CustomLightData>ambient_overrides: OrderedHashMap<String, CustomCellAmbient>output_dir: Option<PathBuf>save_config: boolexcluded_id_regexes: Vec<Regex>excluded_plugin_regexes: Vec<Regex>light_regexes: Vec<(Regex, CustomLightData)>ambient_regexes: Vec<(Regex, CustomCellAmbient)>

Implementations

Source

impl LightConfig

Primarily exists to provide default implementations for field values

pub fn get( light_args: LightArgs, openmw_config: &OpenMWConfiguration, ) -> Result<LightConfig, Error>

Gives back the lightconfig adjacent to openmw.cfg when called use_classic dictates whether or not a fixed radius of 2.0 will be used on orange-y lights and whether or not to disable interior sunlight the latter field is not de/serializable and can only be used via the –classic argument

Errors

Returns filesystem errors encountered while reading or writing lightconfig.toml, or while resolving the fallback output directory.

pub fn is_excluded_plugin(&self, plugin_path: &Path) -> bool

pub fn is_excluded_id(&self, record_id: &str) -> bool